#
# spec file for package noise
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 0.4.x
%define soname noise-core0
Name:           noise
Version:        0.4.2
Release:        lp150.2.1
Summary:        The official Elementary music player
License:        GPL-3.0
Group:          Productivity/Multimedia/Sound/Players
Url:            https://launchpad.net/noise
Source:         https://launchpad.net/noise/%{_version}/%{version}/+download/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM -- Read the embedded cover art (#89)
Patch0:         noise-0.4.2-gst.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.28.0
BuildRequires:  pkgconfig(dbusmenu-glib-0.4)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libaccounts-glib)
BuildRequires:  pkgconfig(libgda-5.0)
BuildRequires:  pkgconfig(libgpod-1.0)
BuildRequires:  pkgconfig(libgsignon-glib)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpeas-1.0)
BuildRequires:  pkgconfig(libpeas-gtk-1.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(taglib_c)
BuildRequires:  pkgconfig(zeitgeist-2.0)
Requires:       libgda-5_0-sqlite
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
Noise is a GTK+ audio player with a focus on music and libraries. It
handles external devices, CDs, and album art. Noise utilises Granite
for a consistent and slick UI.

%package -n   lib%{soname}
Summary:        A library for a simple Graphical User Interface
Group:          System/GUI/Other

%description -n lib%{soname}
Noise is a GTK+ audio player with a focus on music and libraries. It
handles external devices, CDs, and album art. Noise utilises Granite
for a consistent and slick UI.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Other
Requires:       lib%{soname} = %{version}

%description    devel
Development and header files for package %{name}.

%lang_package

%prep
%setup -q
%patch0 -p1

sed -i 's/metainfo/appdata/' $(grep -rwl metainfo)

%build
%cmake \
  -DBUILD_PLUGINS=OFF \
  -DGSETTINGS_COMPILE=OFF
make %{?_smp_mflags} V=1

%install
%cmake_install

%suse_update_desktop_file org.pantheon.noise

%fdupes %{buildroot}%{_datadir}/locale/
%fdupes %{buildroot}%{_datadir}/icons/

%find_lang %{name}

%post
%glib2_gsettings_schema_post
%desktop_database_post
%icon_theme_cache_post

%postun
%glib2_gsettings_schema_postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n lib%{soname} -p /sbin/ldconfig
%postun -n lib%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/org.pantheon.noise.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/org.pantheon.noise.appdata.xml
%{_datadir}/glib-2.0/schemas/org.pantheon.noise.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*.??g

%files -n lib%{soname}
%defattr (-,root,root)
%{_libdir}/lib%{name}-core.so.*

%files devel
%defattr (-,root,root)
%{_libdir}/lib%{name}-core.so
%{_libdir}/pkgconfig/%{name}-core.pc
%dir %{_includedir}/%{name}-core/
%{_includedir}/%{name}-core/*.h
%{_datadir}/vala/vapi/%{name}-core.*

%files lang -f %{name}.lang
%defattr (-,root,root)

%changelog
* Sat Mar 24 2018 avvissu@yandex.by
- Read the embedded cover art (noise-0.4.2-gst.patch)
* Tue Nov 28 2017 avvissu@yandex.by
- Update to 0.4.2:
  * Remove libpeas gtk 1.0.vapi (#93)
  * Remove unused make dist (#87)
  * Remove unused local variable rating_search (#85)
  * Update fsf address (#84)
  * Change the queue mechanism to make it less confusing (#65)
  * clean up preferences window (#80)
  * Rewrite prefs dialog in GObject-style (#76)
  * EQ: Add margin between widgets and expand combo (#75)
  * Detect library changes at startup (#69)
  * URI Filter : Search and SmartPlaylist (#66)
  * Rewrite SyncWarningDialog as a subclass of Gtk.Dialog (#64)
  * Clean up some whitespace
  * LibraryWindow.vala: Code Style fixes (#56)
  * valign searchbar and fix flat eq toggle (#55)
* Sat Jul 29 2017 avvissu@yandex.by
- Update to 0.4.1:
  * remove about dialog (#46)
  * Update AppData URLs (#45)
  * Update .gitignore (#43)
  * Create CODE_OF_CONDUCT.md (#40)
* Sat Apr 22 2017 avvissu@yandex.by
- Update to 0.4.0.3:
  * Create README.md and remove old files (#32)
  * Add the release information to the AppData.xml to provide
    appcenter support
  * Launchpad automatic translations update.
  * Fix build with vala 0.35.6
  * Fix lp#1623663
  * Update Header to correct LGPL-2+
  * For further information or changes, please contact me.
  * Use the correct printf arguments
- Drop noise-0.4.0.2-vala-0.36.patch (fixed)
* Sat Apr  1 2017 sor.alexei@meowr.ru
- Add noise-0.4.0.2-vala-0.36.patch: Fix build with vala >= 0.36.
* Fri Dec  2 2016 avvissu@yandex.by
- Update to 0.4.0.2:
  * Fix type mismatches of arguments/variables
  * Fix "static const ..." valac warnings
  * Use new class "rounded" to set rounded bottom window corners
  * Launchpad automatic translations update.
* Thu Nov 24 2016 jengelh@inai.de
- Update descriptions
* Sat Sep 10 2016 mailaender@opensuse.org
- update to version 0.4
* Sun Sep  6 2015 and.november@opensuse.org
- initial package for openSUSE
